#import <Foundation/Foundation.h>

//! Project version number for FlybitsSDK.
FOUNDATION_EXPORT double FlybitsSDKVersionNumber;

//! Project version string for FlybitsSDK.
FOUNDATION_EXPORT const unsigned char FlybitsSDKVersionString[];

// In this header, you should import all the public headers of your framework using statements like #import <FlybitsSDK/PublicHeader.h>
